<div class="end-of-article-video">
  <h2 class="recirc-title">{{ recirc_text }}</h2>
  <bulbs-video
    twitter-handle="{{ twitter_handle }}"
    src="{{ video_src }}"
    mobile-title="Play Video"
    disable-meta-link
    enable-poster-meta>
  </bulbs-video>
  <bulbs-video-meta class="mobile-meta" src="{{ video_src }}" disable-meta-link/>
</div>